uniform sampler2DShadow shadowMap;
uniform sampler2D Texture1;
varying vec4 projCoord;

varying vec3 normal;
varying vec3 v;
varying vec3 lightvec;


float lookup (float x, float y)
{
   float depth = shadow2DProj(shadowMap, projCoord + vec4(x, y,0.0,0.0) * 0.03).r;
   return depth;
}

void main ()
{
	/* TEXTURE-UNIT 0 .... Shadow-Map */
	/* TEXTURE-UNIT 1 .... DIFFUSE TEXTUR */

    /* 1. Illumination */
    vec3 Eye             = normalize(-v);
    vec3 Reflected       = normalize( reflect( -lightvec, normal )); 
 
    vec4 IAmbient        = gl_LightSource[0].ambient * gl_FrontMaterial.ambient;
    vec4 IDiffuse        = gl_LightSource[0].diffuse * gl_FrontMaterial.diffuse * max(dot(normal, lightvec), 0.0);
    vec4 clr             = gl_FrontLightModelProduct.sceneColor + IAmbient + IDiffuse;

	/* 2. Texturing */
	vec4 clrTex;
	clrTex = texture2D(Texture1, vec2(gl_TexCoord[1]));

    /* 3. Shadow */
	const float kTransparency = 0.3;
	projCoord -= 0.003f;

	float rValue = 0.0;
	
	/* Antialiasing */
	rValue += lookup (-0.5, -0.5);
	rValue += lookup (0.5, -0.5);
	rValue += lookup (-0.5, 0.5);
	rValue += lookup (0.5, 0.5);
	
	rValue = (rValue * 0.25) + kTransparency;
	rValue = clamp(rValue, 0.0, 1.0);

	vec3 coordPos  = projCoord.xyz / projCoord.w;

    /* Draw Fragment */
	if(coordPos.x >= 0.0 && coordPos.y >= 0.0 && coordPos.x <= 1.0 && coordPos.y <= 1.0 )
   	{
		gl_FragColor = clr * clrTex * rValue;
	}
	else
	{
		gl_FragColor = clr * clrTex;
	}
}

